@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2001 Dug Song <dugsong@monkey.org>
  *
- * $Id: eth-dlpi.c,v 1.14 2002/01/20 21:23:27 dugsong Exp $
+ * $Id: eth-dlpi.c,v 1.15 2003/03/06 04:38:35 dugsong Exp $
  */
 
 #include "config.h"
@@ -94,7 +94,7 @@ strioctl(int fd, int cmd, int len, char *dp)
 #define ND_GET	('N' << 8 + 0)
 
 static int
-eth_match_ppa(eth_t *e, char *device)
+eth_match_ppa(eth_t *e, const char *device)
 {
 	char *p, dev[16], buf[256];
 	int len, ppa;
