@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: route-hpux.c,v 1.6 2002/01/20 21:23:28 dugsong Exp $
+ * $Id: route-hpux.c,v 1.9 2003/03/16 19:29:45 dugsong Exp $
  */
 
 #include "config.h"
@@ -15,10 +15,10 @@
 
 #include <net/route.h>
 
-#include <assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 
 #include "dnet.h"
@@ -42,21 +42,19 @@ route_open(void)
 }
 
 int
-route_add(route_t *r, const struct addr *dst, const struct addr *gw)
+route_add(route_t *r, const struct route_entry *entry)
 {
 	struct rtentry rt;
 	
-	assert(r != NULL && dst != NULL && gw != NULL);
-
 	memset(&rt, 0, sizeof(rt));
 
-	if (addr_ntos(dst, &rt.rt_dst) < 0 ||
-	    addr_ntos(gw, &rt.rt_gateway) < 0)
+	if (addr_ntos(&entry->route_dst, &rt.rt_dst) < 0 ||
+	    addr_ntos(&entry->route_gw, &rt.rt_gateway) < 0)
 		return (-1);
 
-	if (dst->addr_bits < IP_ADDR_BITS) {
+	if (entry->route_dst.addr_bits < IP_ADDR_BITS) {
 		rt.rt_flags = RTF_UP | RTF_GATEWAY;
-		if (addr_btom(dst->addr_bits, &rt.rt_subnetmask,
+		if (addr_btom(entry->route_dst.addr_bits, &rt.rt_subnetmask,
 		    IP_ADDR_LEN) < 0)
 			return (-1);
 	} else {
@@ -67,20 +65,18 @@ route_add(route_t *r, const struct addr *dst, const struct addr *gw)
 }
 
 int
-route_delete(route_t *r, const struct addr *dst)
+route_delete(route_t *r, const struct route_entry *entry)
 {
 	struct rtentry rt;
 
-	assert(r != NULL && dst != NULL);
-
 	memset(&rt, 0, sizeof(rt));
 
-	if (addr_ntos(dst, &rt.rt_dst) < 0)
+	if (addr_ntos(&entry->route_dst, &rt.rt_dst) < 0)
 		return (-1);
 
-	if (dst->addr_bits < IP_ADDR_BITS) {
+	if (entry->route_dst.addr_bits < IP_ADDR_BITS) {
 		rt.rt_flags = RTF_UP;
-		if (addr_btom(dst->addr_bits, &rt.rt_subnetmask,
+		if (addr_btom(entry->route_dst.addr_bits, &rt.rt_subnetmask,
 		    IP_ADDR_LEN) < 0)
 			return (-1);
 	} else {
@@ -91,18 +87,23 @@ route_delete(route_t *r, const struct addr *dst)
 }
 
 int
-route_get(route_t *r, const struct addr *dst, struct addr *gw)
+route_get(route_t *r, struct route_entry *entry)
 {
 	struct rtreq rtr;
 
-	assert(r != NULL && dst != NULL && gw != NULL);
-
 	memset(&rtr, 0, sizeof(rtr));
-	memcpy(&rtr.rtr_destaddr, &dst->addr_ip, IP_ADDR_LEN);
-	
-	if (dst->addr_bits < IP_ADDR_BITS)
-		addr_btom(dst->addr_bits, &rtr.rtr_subnetmask, IP_ADDR_LEN);
-	
+
+	/* XXX - gross hack for default route */
+	if (entry->route_dst.addr_ip == IP_ADDR_ANY) {
+		rtr.rtr_destaddr = htonl(0x60060606);
+		rtr.rtr_subnetmask = 0xffffffff;
+	} else {
+		memcpy(&rtr.rtr_destaddr, &entry->route_dst.addr_ip,
+		    IP_ADDR_LEN);
+		if (entry->route_dst.addr_bits < IP_ADDR_BITS)
+			addr_btom(entry->route_dst.addr_bits,
+			    &rtr.rtr_subnetmask, IP_ADDR_LEN);
+	}
 	if (ioctl(r->fd, SIOCGRTENTRY, &rtr) < 0)
 		return (-1);
 
@@ -110,10 +111,10 @@ route_get(route_t *r, const struct addr *dst, struct addr *gw)
 		errno = ESRCH;
 		return (-1);
 	}
-	gw->addr_type = ADDR_TYPE_IP;
-	gw->addr_bits = IP_ADDR_BITS;
-	memcpy(&gw->addr_ip, &rtr.rtr_gwayaddr, IP_ADDR_LEN);
-
+	entry->route_gw.addr_type = ADDR_TYPE_IP;
+	entry->route_gw.addr_bits = IP_ADDR_BITS;
+	memcpy(&entry->route_gw.addr_ip, &rtr.rtr_gwayaddr, IP_ADDR_LEN);
+	
 	return (0);
 }
 
@@ -123,7 +124,7 @@ int
 route_loop(route_t *r, route_handler callback, void *arg)
 {
 	struct nmparms nm;
-	struct addr dst, gw;
+	struct route_entry entry;
 	mib_ipRouteEnt rtentries[MAX_RTENTRIES];
 	int fd, i, n, ret;
 	
@@ -141,8 +142,8 @@ route_loop(route_t *r, route_handler callback, void *arg)
 	}
 	close_mib(fd);
 
-	dst.addr_type = gw.addr_type = ADDR_TYPE_IP;
-	dst.addr_bits = gw.addr_bits = IP_ADDR_BITS;
+	entry.route_dst.addr_type = entry.route_gw.addr_type = ADDR_TYPE_IP;
+	entry.route_dst.addr_bits = entry.route_gw.addr_bits = IP_ADDR_BITS;
 	n /= sizeof(*rtentries);
 	ret = 0;
 	
@@ -151,11 +152,12 @@ route_loop(route_t *r, route_handler callback, void *arg)
 		    rtentries[i].Type != NMREMOTE)
 			continue;
 		
-		dst.addr_ip = rtentries[i].Dest;
-		addr_mtob(&rtentries[i].Mask, IP_ADDR_LEN, &dst.addr_bits);
-		gw.addr_ip = rtentries[i].NextHop;
+		entry.route_dst.addr_ip = rtentries[i].Dest;
+		addr_mtob(&rtentries[i].Mask, IP_ADDR_LEN,
+		    &entry.route_dst.addr_bits);
+		entry.route_gw.addr_ip = rtentries[i].NextHop;
 
-		if ((ret = callback(&dst, &gw, arg)) != 0)
+		if ((ret = callback(&entry, arg)) != 0)
 			break;
 	}
 	return (ret);
@@ -164,8 +166,6 @@ route_loop(route_t *r, route_handler callback, void *arg)
 route_t *
 route_close(route_t *r)
 {
-	assert(r != NULL);
-
 	if (r->fd > 0)
 		close(r->fd);
 	free(r);
