@@ -3,13 +3,13 @@
  *
  * Copyright (c) 2002 Dug Song <dugsong@monkey.org>
  *
- * $Id: route-win32.c,v 1.7 2002/02/04 05:05:11 dugsong Exp $
+ * $Id: route-win32.c,v 1.8 2003/03/21 04:03:05 dugsong Exp $
  */
 
 #include "config.h"
 
 #include <ws2tcpip.h>
-#include <Iphlpapi.h>
+#include <iphlpapi.h>
 
 #include <errno.h>
 #include <stdlib.h>
@@ -109,7 +109,8 @@ route_loop(route_t *route, route_handler callback, void *arg)
 	ULONG len;
 	struct route_entry entry;
 	u_char buf[4096];
-	int i, ret;
+	u_long i;
+	int ret;
 	
 	ipftable = (MIB_IPFORWARDTABLE *)buf;
 	len = sizeof(buf);
